@@ -104,7 +104,6 @@ def test_fs_file_storage(tmp_upath, as_filesystem):
             ),
             ("data",): DataIndexEntry(
                 key=("data",),
-                meta=Meta(isdir=True),
             ),
         }
     )
@@ -114,8 +113,13 @@ def test_fs_file_storage(tmp_upath, as_filesystem):
     fs = DataFileSystem(index)
     assert fs.exists("foo")
     assert fs.cat("foo") == b"foo\n"
-    assert fs.ls("/", detail=False) == ["/foo", "/data"]
-    assert fs.ls("/", detail=True) == [fs.info("/foo"), fs.info("/data")]
+    assert sorted(fs.ls("/", detail=False)) == sorted(["/foo", "/data"])
+    assert sorted(
+        fs.ls("/", detail=True), key=lambda entry: entry["name"]
+    ) == sorted(
+        [fs.info("/foo"), fs.info("/data")],
+        key=lambda entry: entry["name"],
+    )
     assert fs.cat("/data/bar") == b"bar\n"
     assert fs.cat("/data/baz") == b"baz\n"
     assert sorted(fs.ls("/data", detail=False)) == sorted(
